@@ -1,4 +1,5 @@
-from typing import List, Optional, Tuple, Union
+import importlib.metadata as importlib_metadata
+from typing import Generator, List, Optional, Tuple, Union
 
 import grpc
 from nibiru_proto.proto.cosmos.auth.v1beta1 import auth_pb2 as auth_type
@@ -42,6 +43,7 @@ class GrpcClient:
             if insecure
             else grpc.secure_channel(network.grpc_endpoint, credentials)
         )
+
         self.insecure = insecure
         self.stubCosmosTendermint = tendermint_query_grpc.ServiceStub(
             self.chain_channel
@@ -59,6 +61,11 @@ class GrpcClient:
         self.perp = nibiru.query_clients.PerpQueryClient(self.chain_channel)
         self.vpool = nibiru.query_clients.VpoolQueryClient(self.chain_channel)
 
+        # Assert that we use the correct version of the chain
+        nibiru_proto_version = importlib_metadata.version("nibiru_proto")
+
+        assert nibiru_proto_version.split(".") >= self.get_version()[1:].split(".")
+
     def close_chain_channel(self):
         self.chain_channel.close()
 
@@ -66,11 +73,55 @@ class GrpcClient:
         block = self.get_latest_block()
         self.timeout_height = block.block.header.height + DEFAULT_TIMEOUTHEIGHT
 
+    def get_block_by_height(
+        self, height: int
+    ) -> tendermint_query.GetBlockByHeightResponse:
+        req = tendermint_query.GetBlockByHeightRequest(height=height)
+        return self.stubCosmosTendermint.GetBlockByHeight(req)
+
+    def get_blocks_by_height(
+        self, start_height: int, end_height: int = None
+    ) -> Generator[tendermint_query.GetBlockByHeightResponse, None, None]:
+        """
+        Iterate through all the blocks in the chain and yield the output of the block one by one.
+        If no end_height is specified, iterate until the current latest block is reached.
+
+        Args:
+            start_height (int): The starting block height
+            end_height (int, optional): The last block height to query. Defaults to None.
+
+        Yields:
+            Generator[tendermint_query.GetBlockByHeightResponse, None, None]
+        """
+        if end_height is None:
+            height = start_height
+            while True:
+                try:
+                    yield self.get_block_by_height(height)
+                    height += 1
+                except:
+                    break
+        else:
+            for height in range(start_height, end_height):
+                yield self.get_block_by_height(height)
+
     # default client methods
     def get_latest_block(self) -> tendermint_query.GetLatestBlockResponse:
         req = tendermint_query.GetLatestBlockRequest()
         return self.stubCosmosTendermint.GetLatestBlock(req)
 
+    def get_version(self) -> tendermint_query.GetLatestBlockResponse:
+        req = tendermint_query.GetNodeInfoRequest()
+        version = self.stubCosmosTendermint.GetNodeInfo(req).application_version.version
+
+        if version[0] != "v":
+            version = "v" + str(version)
+
+        return version
+
+    def get_latest_block_height(self) -> int:
+        return self.get_latest_block().block.header.height
+
     def get_account(self, address: str) -> Optional[auth_type.BaseAccount]:
         try:
             account_any = self.stubAuth.Account(
